Flask-MakeStatic
================

.. image:: https://travis-ci.org/DasIch/Flask-MakeStatic.png?branch=master
   :target: https://travis-ci.org/DasIch/Flask-MakeStatic

Flask-MakeStatic is a simple BSD licensed Flask_ extension that makes it easy
to compile assets such as sass_ or coffeescript_ files to static files such as
css or javascript files.

Take a look at the documentation_ for more information.


.. _Flask: http://flask.pocoo.org/
.. _sass: http://sass-lang.org/
.. _coffeescript: http://coffeescript.org/
.. _documentation: https://flask-makestatic.readthedocs.org/
